@@ -5,14 +5,14 @@ use warnings;
 
 # Added by eilara as hack around caller() core dump
 # NOTE: Now we've switched to Sub::Uplevel can this be removed? --ADAMK
-use Carp::Heavy           (); 
-use Carp                  ();
-use Sub::Uplevel          ();
-use Aspect::Advice        ();
-use Aspect::Advice::Hook  ();
-use Aspect::AdviceContext ();
+use Carp::Heavy            (); 
+use Carp                   ();
+use Sub::Uplevel           ();
+use Aspect::Hook           ();
+use Aspect::Advice         ();
+use Aspect::Context::After ();
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -62,7 +62,7 @@ sub _install {
 		# Generate the new function
 		no warnings 'redefine';
 		eval <<"END_PERL"; die $@ if $@;
-		package Aspect::Advice::Hook;
+		package Aspect::Hook;
 
 		*$NAME = sub $PROTOTYPE {
 			# Is this a lexically scoped hook that has finished
@@ -88,13 +88,13 @@ sub _install {
 				}
 
 				# Create the context
-				my \$context = Aspect::AdviceContext->new(
+				my \$context = bless {
 					type     => 'after',
 					pointcut => \$pointcut,
 					params   => \\\@_,
 					original => \$original,
 					\%\$runtime,
-				);
+				}, 'Aspect::Context::After';
 
 				# Execute the advice code
 				() = &\$code(\$context);
@@ -126,13 +126,13 @@ sub _install {
 				}
 
 				# Create the context
-				my \$context = Aspect::AdviceContext->new(
+				my \$context = bless {
 					type     => 'after',
 					pointcut => \$pointcut,
 					params   => \\\@_,
 					original => \$original,
 					\%\$runtime,
-				);
+				}, 'Aspect::Context::After';
 
 				# Execute the advice code
 				my \$dummy = &\$code(\$context);
@@ -163,13 +163,13 @@ sub _install {
 				}
 
 				# Create the context
-				my \$context = Aspect::AdviceContext->new(
+				my \$context = bless {
 					type     => 'after',
 					pointcut => \$pointcut,
 					params   => \\\@_,
 					original => \$original,
 					\%\$runtime,
-				);
+				}, 'Aspect::Context::After';
 
 				# Execute the advice code
 				&\$code(\$context);
